# REDAST - Remote Data Storage

Redast provides a flexible interface for storing data in different types of storages.
The organization of data storage is carried out according to the principle of a data lake.

```bash
pip install redast
```

[Documentation](https://rilshok.github.io/redast)
